(define-module (glicid packages glicid)
               #:use-module (guix packages)
               #:use-module (guix download)
               #:use-module (guix git-download)
               #:use-module (guix build-system cmake)
               #:use-module (guix build-system gnu)
               #:use-module (guix build-system python)
               #:use-module (guix build-system ruby)
               #:use-module (gnu packages autotools)
               #:use-module (gnu packages bison)
               #:use-module (gnu packages chemistry)
               #:use-module (gnu packages flex)
               #:use-module (gnu packages fontutils)
               #:use-module (gnu packages gcc)
               #:use-module (gnu packages image)
               #:use-module (gnu packages messaging)
               #:use-module (gnu packages mpi)
               #:use-module (gnu packages networking)
               #:use-module (gnu packages perl)
               #:use-module (gnu packages pkg-config)
               #:use-module (gnu packages ruby)
               #:use-module (gnu packages sphinx)
               #:use-module (gnu packages xorg)
               #:use-module ((guix licenses) #:prefix license:)
               )

(define-public glicid-librdkafka-09
               (package
                 (inherit librdkafka)
                 (name "glicid-librdkafka-09")
                 (version "0.9.2")
                 (source (origin
                           (method url-fetch)
                           (uri (string-append "https://github.com/edenhill/librdkafka/archive/v" version ".tar.gz"))
                           (sha256 (base32 "0938yn1msaq8xcj5z7b3jcdy6rslh9kxmvz01r8rdcgbarlvchy2"))))))

(define-public glicid-x2go
               (package
                 (name "glicid-x2go")
                 (version "4.1.0.3")
                 (source (origin
                           (method url-fetch)
                           (uri (string-append "https://code.x2go.org/releases/source/x2goserver/x2goserver-" version ".tar.gz"))
                           (sha256 (base32 "1l6wd708kbipib4ldprfiihqmj4895nifg0bkws4x97majislxk7"))))
                 (native-inputs `(("autoconf" ,autoconf)
                                  ("automake" ,automake)
                                  ("libtool" ,libtool)))
                 (inputs `(("perl" ,perl)))
                 (build-system gnu-build-system)
                 (synopsis "X2go")
                 (description "X2go")
                 (license license:gpl2+) ;not checked
                 (home-page "https://wiki.x2go.org")))

(define-public glicid-gromacs-openmpi
               (package
                 (inherit gromacs)
                 (name "glicid-gromacs-openmpi")
                 (inputs `(("openmpi" ,openmpi)
                           ,@(package-inputs gromacs)))
                 (build-system cmake-build-system)
                 (arguments
                   `(#:configure-flags (list "-DGMX_DEVELOPER_BUILD=on"
                                             "-DGMX_USE_LMFIT=EXTERNAL"
                                             "-DGMX_BUILD_OWN_FFTW=off"
                                             "-DGMX_EXTERNAL_BLAS=on"
                                             "-DGMX_EXTERNAL_LAPACK=on"
                                             "-DGMX_EXTERNAL_TNG=on"
                                             "-DGMX_EXTERNAL_ZLIB=on"
                                             "-DGMX_EXTERNAL_TINYXML2=on"
                                             "-DGMX_MPI=on"
                                             "-DCMAKE_C_COMPILER=mpicc"
                                             "-DCMAKE_CXX_COMPILER=mpicxx"
                                             "-DGMX_DOUBLE=off"
                                             "-DGMX_OPENMP=on"
                                             "-DGMX_SIMD=AVX2_256"
                                             (string-append "-DTinyXML2_DIR=" (assoc-ref %build-inputs "tinyxml2"))
                                             (string-append "-DSPHINX_EXECUTABLE_VERSION="
                                                            ,(package-version python-sphinx)))
                     #:tests? #f
                     #:phases (modify-phases %standard-phases
                                             (add-after 'unpack 'fixes
                                                        (lambda* (#:key inputs #:allow-other-keys)
                                                                 (delete-file-recursively "src/external/lmfit")
                                                                 (delete-file-recursively "src/external/clFFT")
                                                                 (delete-file-recursively "src/external/fftpack")
                                                                 (delete-file-recursively "src/external/build-fftw")
                                                                 (delete-file-recursively "src/external/tng_io")
                                                                 (delete-file-recursively "src/external/tinyxml2")
                                                                 (delete-file-recursively "src/external/googletest")
                                                                 (copy-recursively (assoc-ref inputs "googletest-source") "src/external/googletest")
                                                                 (substitute* "src/gromacs/hardware/tests/hardwaretopology.cpp"
                                                                              (("TEST\\(HardwareTopologyTest, HwlocExecute\\)")
                                                                               "void __guix_disabled()"))
                                                                 #t)))))))

(define-public glicid-python-nbxmpp
               (package
                 (inherit python-nbxmpp)
                 (name "glicid-python-nbxmpp")
                 (version "1.0.2")
                 (source (origin
                           (method url-fetch)
                           (uri (pypi-uri "nbxmpp" version))
                           (sha256 (base32 "0vw5drr077w9ks4crnw6pwa4735ycyjdcm54knc3w4in4x5027wr")))) ))

(define-public glicid-motif
               (package
                 (name "glicid-motif")
                 (version "2.3.8")
                 (source (origin
                           (method url-fetch)
                           (uri (string-append "mirror://sourceforge/motif/Motif%202.3.8%20Source%20Code/motif-2.3.8.tar.gz"))
                           (file-name (string-append name "-" version ".tar.gz"))
                           (sha256 (base32 "1rxwkrhmj8sfg7dwmkhq885valwqbh26d79033q7vb7fcqv756w5"))))
                 (build-system gnu-build-system)
                 (arguments
                   `(#:make-flags
                     (list (string-append "PREFIX=" %output)
                           (string-append "CPPFLAGS=-I" (assoc-ref %build-inputs "freetype") "/include/freetype2")
                           "V=1")))
                 (inputs `(("libxext" ,libxext)
                           ("libx11" ,libx11)
                           ("freetype" ,freetype)
                           ("libxft" ,libxft)
                           ("xbitmaps" ,xbitmaps)
                           ("pkg-config" ,pkg-config)
                           ("flex" ,flex)
                           ("bison" ,bison)
                           ("libxt" ,libxt)))
                 (synopsis "Motif")
                 (description "Motif ")
                 (home-page "https://sourceforge.net/untested")
                 (license license:gpl2+)))

(define-public glicid-xmgrace
               (package
                 (name "glicid-xmgrace")
                 (version "5.1.25")
                 (source (origin
                           (method git-fetch)
                           (uri (git-reference
                                  (url "https://oauth2:glpat-RsX2GjsD2WrzXubiJeou@gitlab.univ-nantes.fr/CCIPL/legacy_code_mirror/grace.git")
                                  (commit (string-append "v" version))))
                           (file-name (git-file-name name version))
                           (sha256 (base32 "1wb8v0q8xa2akas0swpgdgw1s66i50k7kh1g2f894hnk91fzx56z"))))
                 (build-system gnu-build-system)
                 (arguments
                   `(#:phases (modify-phases %standard-phases
                                             (add-after 'configure 'patch-/bin/sh
                                                        (lambda _
                                                          (substitute* '("Make.conf")
                                                                       (("/bin/sh")
                                                                        (which "bash"))))))))
                 (inputs `(("libx11" ,libx11)
                           ("libxft" ,libxft)
                           ("libxt" ,libxt)
                           ("libxpm" ,libxpm)
                           ("libxext" ,libxext)
                           ("autoconf" ,autoconf)
                           ("glicid-motif" ,glicid-motif)
                           ("fontconfig" ,fontconfig)
                           ("gfortran" ,gfortran)
                           ("libjpeg-turbo" ,libjpeg-turbo) ))
                 (synopsis "Xmgrace")
                 (description "xmgrace")
                 (home-page "https://sourceforge.net/untested")
                 (license license:gpl2+) ))

;(define-public ruby-asciidoctor-revealjs
;               (package
;                 (name "ruby-asciidoctor-revealjs")
;                 (version "4.1.0")
;                 (source (origin
;                           (method url-fetch)
;                           (uri (rubygems-uri "asciidoctor-revealjs" version))
;                           (sha256
;                             (base32
;                               "03vmbcc3x059h17ry4qwk1p0yar9wgh87l2qssi307gy45cjw2mq"))))
;                 (build-system ruby-build-system)
;                 (arguments
;                   '(#:tests? #f))
;                 (propagated-inputs `(("ruby-asciidoctor" ,ruby-asciidoctor)
;                                      ("ruby-concurrent" ,ruby-concurrent)
;                                      ("ruby-asciidoctor-kroki" ,ruby-asciidoctor-kroki)
;                                      ("ruby-thread-safe" ,ruby-thread-safe)))
;                 (synopsis "Converts AsciiDoc documents into HTML5 presentations designed to be executed by the reveal.js presentation framework.")
;                 (description "Converts AsciiDoc documents into HTML5 presentations designed to be executed by the reveal.js presentation framework.")
;                 (home-page "https://github.com/asciidoctor/asciidoctor-reveal.js")
;                 (license license:expat)))

;(define-public ruby-asciidoctor-kroki
;               (package
;                 (name "ruby-asciidoctor-kroki")
;                 (version "0.4.0")
;                 (source (origin
;                           (method url-fetch)
;                           (uri (rubygems-uri "asciidoctor-kroki" version))
;                           (sha256 (base32 "13gx22xld4rbxxirnsxyrsajy9v666r8a4ngms71611af5afgk6w"))))
;                 (build-system ruby-build-system)
;                 (arguments
;                   '(#:tests? #f))
;                 (propagated-inputs `(("ruby-asciidoctor" ,ruby-asciidoctor)))
;                 (synopsis "An extension for Asciidoctor to convert diagrams to images using https://kroki.io")
;                 (description "An extension for Asciidoctor to convert diagrams to images using https://kroki.io")
;                 (home-page "https://github.com/Mogztter/asciidoctor-kroki")
;                 (license license:expat)))
