(define-module (glicid packages vpn)
               #:use-module (guix)
               #:use-module (ice-9 match)
               #:use-module ((guix licenses) #:prefix license:)
               #:use-module (guix utils)
               #:use-module (guix download)
               #:use-module (guix git-download)
               #:use-module (guix packages)
               #:use-module (guix build-system copy)
               #:use-module (guix build-system go)
               #:use-module (nonguix build-system binary)
               #:use-module (gnu packages certs)
               #:use-module (gnu packages dns)
               #:use-module (gnu packages gl)
               #:use-module (gnu packages golang)
               #:use-module (gnu packages golang-build)
               #:use-module (gnu packages golang-web)
               #:use-module (gnu packages golang-xyz)
               #:use-module (gnu packages linux)
               #:use-module (gnu packages xorg)
               )

(define %netbird-version "0.50.1")

(define %netbird-synopsis "NetBird combines a configuration-free peer-to-peer private network and a centralized access control system in a single platform, making it easy to create secure private networks for your organization or home.
  Connect. NetBird creates a WireGuard-based overlay network that automatically connects your machines over an encrypted tunnel, leaving behind the hassle of opening ports, complex firewall rules, VPN gateways, and so forth.
  Secure. NetBird enables secure remote access by applying granular access policies while allowing you to manage them intuitively from a single place. Works universally on any infrastructure.")

(define %netbird-homepage "https://github.com/netbirdio/netbird")

(define-public netbird-cli
               (package
                 (name "netbird-cli")
                 (version %netbird-version)
                 (source (origin
                           (method url-fetch)
                           (uri (string-append "https://github.com/netbirdio/netbird/releases/download/v" version "/netbird_" version "_linux_amd64.tar.gz"))
                           (sha256 (base32 "0y7zxs9pxpwkpn34jq9whc2cfd13smfqw8s4vnj6d0v9vriwpg9a"))))
                 (build-system copy-build-system)
                 (arguments
                   `(#:install-plan `(("netbird" "/bin/"))))
                 (propagated-inputs (list openresolv iptables nftables ebtables le-certs nss-certs))
                 (synopsis %netbird-synopsis)
                 (description "netbird client cli program. dirty version from github artifacts.")
                 (home-page %netbird-homepage)
                 (license license:expat)))

(define-public netbird-ui
               (package
                 (name "netbird-ui")
                 (version %netbird-version)
                 (source (origin
                           (method url-fetch)
                           (uri (string-append "https://github.com/netbirdio/netbird/releases/download/v" version "/netbird-ui-linux_" version "_linux_amd64.tar.gz"))
                           (sha256 (base32 "0b65s7gzf7hl342di7g0cz4j68qq3k5ay75yh5qny3s8vswi45k8"))))
                 (build-system binary-build-system)
                 (inputs (list libx11 libglvnd))
                 (arguments
                   `(#:install-plan `(("netbird-ui" "/bin/"))
                     #:patchelf-plan `(("netbird-ui" ("libx11" "libglvnd")))
                     #:strip-binaries? #f))
                 (synopsis %netbird-synopsis)
                 (description "netbird client ui program. dirty version from github artifacts.")
                 (home-page %netbird-homepage)
                 (license license:expat)))
